<?php

return [
    'Names' => [
        'aa' => 'அஃபார்',
        'ab' => 'அப்காஜியான்',
        'ace' => 'ஆச்சினீஸ்',
        'ach' => 'அகோலி',
        'ada' => 'அதாங்மே',
        'ady' => 'அதகே',
        'ae' => 'அவெஸ்தான்',
        'aeb' => 'துனிசிய அரபு',
        'af' => 'ஆஃப்ரிகான்ஸ்',
        'afh' => 'அஃப்ரிஹிலி',
        'agq' => 'அகெம்',
        'ain' => 'ஐனு',
        'ak' => 'அகான்',
        'akk' => 'அக்கேதியன்',
        'ale' => 'அலூட்',
        'alt' => 'தெற்கு அல்தை',
        'am' => 'அம்ஹாரிக்',
        'an' => 'ஆர்கோனீஸ்',
        'ang' => 'பழைய ஆங்கிலம்',
        'ann' => 'ஒபோலோ',
        'anp' => 'அங்கிகா',
        'ar' => 'அரபிக்',
        'arc' => 'அராமைக்',
        'arn' => 'மபுச்சே',
        'arp' => 'அரபஹோ',
        'ars' => 'நஜ்தி அரபிக்',
        'arw' => 'அராவாக்',
        'as' => 'அஸ்ஸாமீஸ்',
        'asa' => 'அசு',
        'ast' => 'அஸ்துரியன்',
        'atj' => 'அடிகாமேக்வ்',
        'av' => 'அவேரிக்',
        'awa' => 'அவதி',
        'ay' => 'அய்மரா',
        'az' => 'அசர்பைஜானி',
        'ba' => 'பஷ்கிர்',
        'bal' => 'பலூச்சி',
        'ban' => 'பலினீஸ்',
        'bas' => 'பாஸா',
        'be' => 'பெலாருஷியன்',
        'bej' => 'பேஜா',
        'bem' => 'பெம்பா',
        'bez' => 'பெனா',
        'bfq' => 'படகா',
        'bg' => 'பல்கேரியன்',
        'bgn' => 'மேற்கு பலோச்சி',
        'bho' => 'போஜ்பூரி',
        'bi' => 'பிஸ்லாமா',
        'bik' => 'பிகோல்',
        'bin' => 'பினி',
        'bla' => 'சிக்சிகா',
        'bm' => 'பம்பாரா',
        'bn' => 'வங்காளம்',
        'bo' => 'திபெத்தியன்',
        'bpy' => 'பிஷ்ணுப்பிரியா',
        'br' => 'பிரெட்டன்',
        'bra' => 'ப்ராஜ்',
        'brx' => 'போடோ',
        'bs' => 'போஸ்னியன்',
        'bua' => 'புரியாத்',
        'bug' => 'புகினீஸ்',
        'byn' => 'ப்லின்',
        'ca' => 'கேட்டலான்',
        'cad' => 'கேடோ',
        'car' => 'கரீப்',
        'cay' => 'கேயுகா',
        'cch' => 'ஆட்சம்',
        'ccp' => 'சக்மா',
        'ce' => 'செச்சென்',
        'ceb' => 'செபுவானோ',
        'cgg' => 'சிகா',
        'ch' => 'சாமோரோ',
        'chb' => 'சிப்சா',
        'chg' => 'ஷகதை',
        'chk' => 'சூகிசே',
        'chm' => 'மாரி',
        'chn' => 'சினூக் ஜார்கான்',
        'cho' => 'சோக்தௌ',
        'chp' => 'சிபெவ்யான்',
        'chr' => 'செரோகீ',
        'chy' => 'செயேனி',
        'ckb' => 'மத்திய குர்திஷ்',
        'clc' => 'சில்கோடின்',
        'co' => 'கார்சிகன்',
        'cop' => 'காப்டிக்',
        'cr' => 'க்ரீ',
        'crg' => 'மிச்சிஃப்',
        'crh' => 'கிரிமியன் துர்க்கி',
        'crj' => 'தென்கிழக்கு க்ரீ',
        'crk' => 'சமவெளி க்ரீ',
        'crl' => 'வடகிழக்கு க்ரீ',
        'crm' => 'மூஸ் க்ரீ',
        'crr' => 'கரோலினா அல்கோன்குயன்',
        'crs' => 'செசெல்வா க்ரெயோல் பிரெஞ்சு',
        'cs' => 'செக்',
        'csb' => 'கஷுபியன்',
        'csw' => 'சதுப்பு நில க்ரீ',
        'cu' => 'சர்ச் ஸ்லாவிக்',
        'cv' => 'சுவாஷ்',
        'cy' => 'வேல்ஷ்',
        'da' => 'டேனிஷ்',
        'dak' => 'டகோடா',
        'dar' => 'தார்குவா',
        'dav' => 'டைடா',
        'de' => 'ஜெர்மன்',
        'del' => 'டெலாவர்',
        'den' => 'ஸ்லாவ்',
        'dgr' => 'டோக்ரிப்',
        'din' => 'டின்கா',
        'dje' => 'ஸார்மா',
        'doi' => 'டோக்ரி',
        'dsb' => 'லோயர் சோர்பியன்',
        'dua' => 'டுவாலா',
        'dum' => 'மிடில் டச்சு',
        'dv' => 'திவேஹி',
        'dyo' => 'ஜோலா-ஃபோன்யி',
        'dyu' => 'ட்யூலா',
        'dz' => 'பூடானி',
        'dzg' => 'டசாகா',
        'ebu' => 'எம்பு',
        'ee' => 'ஈவ்',
        'efi' => 'எஃபிக்',
        'egy' => 'பண்டைய எகிப்தியன்',
        'eka' => 'ஈகாஜுக்',
        'el' => 'கிரேக்கம்',
        'elx' => 'எலமைட்',
        'en' => 'ஆங்கிலம்',
        'enm' => 'மிடில் ஆங்கிலம்',
        'eo' => 'எஸ்பரேன்டோ',
        'es' => 'ஸ்பானிஷ்',
        'et' => 'எஸ்டோனியன்',
        'eu' => 'பாஸ்க்',
        'ewo' => 'எவோன்டோ',
        'fa' => 'பெர்ஷியன்',
        'fan' => 'ஃபேங்க்',
        'fat' => 'ஃபான்டி',
        'ff' => 'ஃபுலா',
        'fi' => 'ஃபின்னிஷ்',
        'fil' => 'ஃபிலிபினோ',
        'fj' => 'ஃபிஜியன்',
        'fo' => 'ஃபரோயிஸ்',
        'fon' => 'ஃபான்',
        'fr' => 'பிரெஞ்சு',
        'frc' => 'கஜுன் பிரெஞ்சு',
        'frm' => 'மிடில் பிரெஞ்சு',
        'fro' => 'பழைய பிரெஞ்சு',
        'frr' => 'வடக்கு ஃப்ரிஸியான்',
        'frs' => 'கிழக்கு ஃப்ரிஸியான்',
        'fur' => 'ஃப்ரியூலியன்',
        'fy' => 'மேற்கு ஃப்ரிஷியன்',
        'ga' => 'ஐரிஷ்',
        'gaa' => 'கா',
        'gag' => 'காகௌஸ்',
        'gan' => 'கன் சீனம்',
        'gay' => 'கயோ',
        'gba' => 'பயா',
        'gd' => 'ஸ்காட்ஸ் கேலிக்',
        'gez' => 'கீஜ்',
        'gil' => 'கில்பெர்டீஸ்',
        'gl' => 'காலிஸியன்',
        'gmh' => 'மிடில் ஹை ஜெர்மன்',
        'gn' => 'க்வாரனி',
        'goh' => 'பழைய ஹை ஜெர்மன்',
        'gon' => 'கோன்டி',
        'gor' => 'கோரோன்டலோ',
        'got' => 'கோதிக்',
        'grb' => 'க்ரேபோ',
        'grc' => 'பண்டைய கிரேக்கம்',
        'gsw' => 'ஸ்விஸ் ஜெர்மன்',
        'gu' => 'குஜராத்தி',
        'guz' => 'குஸி',
        'gv' => 'மேங்க்ஸ்',
        'gwi' => 'குவிசின்',
        'ha' => 'ஹௌஸா',
        'hai' => 'ஹைடா',
        'hak' => 'ஹக்கா சீனம்',
        'haw' => 'ஹவாயியன்',
        'hax' => 'தெற்கு ஹைடா',
        'he' => 'ஹீப்ரூ',
        'hi' => 'இந்தி',
        'hif' => 'ஃபிஜி இந்தி',
        'hil' => 'ஹிலிகாய்னான்',
        'hit' => 'ஹிட்டைட்',
        'hmn' => 'மாங்க்',
        'ho' => 'ஹிரி மோட்டு',
        'hr' => 'குரோஷியன்',
        'hsb' => 'அப்பர் சோர்பியான்',
        'hsn' => 'சியாங்க் சீனம்',
        'ht' => 'ஹைத்தியன் க்ரியோலி',
        'hu' => 'ஹங்கேரியன்',
        'hup' => 'ஹுபா',
        'hur' => 'ஹல்கோமெலம்',
        'hy' => 'ஆர்மேனியன்',
        'hz' => 'ஹெரேரோ',
        'ia' => 'இன்டர்லிங்வா',
        'iba' => 'இபான்',
        'ibb' => 'இபிபியோ',
        'id' => 'இந்தோனேஷியன்',
        'ie' => 'இன்டர்லிங்',
        'ig' => 'இக்போ',
        'ii' => 'சிசுவான் ஈ',
        'ik' => 'இனுபியாக்',
        'ikt' => 'மேற்கு கனடிய இனுக்டிடுட்',
        'ilo' => 'இலோகோ',
        'inh' => 'இங்குஷ்',
        'io' => 'இடோ',
        'is' => 'ஐஸ்லேண்டிக்',
        'it' => 'இத்தாலியன்',
        'iu' => 'இனுகிடூட்',
        'ja' => 'ஜப்பானியம்',
        'jbo' => 'லோஜ்பன்',
        'jgo' => 'நகொம்பா',
        'jmc' => 'மாசெம்',
        'jpr' => 'ஜூதேயோ-பெர்ஷியன்',
        'jrb' => 'ஜூதேயோ-அராபிக்',
        'jv' => 'ஜாவனீஸ்',
        'ka' => 'ஜார்ஜியன்',
        'kaa' => 'காரா-கல்பாக்',
        'kab' => 'கபாய்ல்',
        'kac' => 'காசின்',
        'kaj' => 'ஜ்ஜூ',
        'kam' => 'கம்பா',
        'kaw' => 'காவி',
        'kbd' => 'கபார்டியன்',
        'kcg' => 'தையாப்',
        'kde' => 'மகொண்டே',
        'kea' => 'கபுவெர்தியானு',
        'kfo' => 'கோரோ',
        'kg' => 'காங்கோ',
        'kgp' => 'கைன்கேங்',
        'kha' => 'காஸி',
        'kho' => 'கோதானீஸ்',
        'khq' => 'கொய்ரா சீனீ',
        'ki' => 'கிகுயூ',
        'kj' => 'குவான்யாமா',
        'kk' => 'கசாக்',
        'kkj' => 'ககோ',
        'kl' => 'கலாலிசூட்',
        'kln' => 'கலின்ஜின்',
        'km' => 'கெமெர்',
        'kmb' => 'கிம்புன்து',
        'kn' => 'கன்னடம்',
        'ko' => 'கொரியன்',
        'koi' => 'கொமி-பெர்ம்யாக்',
        'kok' => 'கொங்கணி',
        'kos' => 'கோஸ்ரைன்',
        'kpe' => 'க்பெல்லே',
        'kr' => 'கனுரி',
        'krc' => 'கராசே-பல்கார்',
        'krl' => 'கரேலியன்',
        'kru' => 'குருக்',
        'ks' => 'காஷ்மிரி',
        'ksb' => 'ஷம்பாலா',
        'ksf' => 'பாஃபியா',
        'ksh' => 'கொலோக்னியன்',
        'ku' => 'குர்திஷ்',
        'kum' => 'கும்யிக்',
        'kut' => 'குடேனை',
        'kv' => 'கொமி',
        'kw' => 'கார்னிஷ்',
        'kwk' => 'குவாக்வாலா',
        'ky' => 'கிர்கிஸ்',
        'la' => 'லத்தின்',
        'lad' => 'லடினோ',
        'lag' => 'லங்கி',
        'lah' => 'லஹன்டா',
        'lam' => 'லம்பா',
        'lb' => 'லக்ஸம்போர்கிஷ்',
        'lez' => 'லெஜ்ஜியன்',
        'lg' => 'கான்டா',
        'li' => 'லிம்பர்கிஷ்',
        'lil' => 'லில்லூயிட்',
        'lkt' => 'லகோடா',
        'lmo' => 'லொம்பார்டு',
        'ln' => 'லிங்காலா',
        'lo' => 'லாவோ',
        'lol' => 'மோங்கோ',
        'lou' => 'லூசியானா க்ரயோல்',
        'loz' => 'லோசி',
        'lrc' => 'வடக்கு லுரி',
        'lsm' => 'சாமியா',
        'lt' => 'லிதுவேனியன்',
        'lu' => 'லுபா-கடாங்கா',
        'lua' => 'லுபா-லுலுலா',
        'lui' => 'லுய்சேனோ',
        'lun' => 'லூன்டா',
        'luo' => 'லுயோ',
        'lus' => 'மிஸோ',
        'luy' => 'லுயியா',
        'lv' => 'லாட்வியன்',
        'mad' => 'மதுரீஸ்',
        'mag' => 'மகாஹி',
        'mai' => 'மைதிலி',
        'mak' => 'மகாசார்',
        'man' => 'மான்டிங்கோ',
        'mas' => 'மாசாய்',
        'mdf' => 'மோக்க்ஷா',
        'mdr' => 'மான்டார்',
        'men' => 'மென்டீ',
        'mer' => 'மெரு',
        'mfe' => 'மொரிசியன்',
        'mg' => 'மலகாஸி',
        'mga' => 'மிடில் ஐரிஷ்',
        'mgh' => 'மகுவா-மீட்டோ',
        'mgo' => 'மேடா',
        'mh' => 'மார்ஷெலீஸ்',
        'mi' => 'மௌரி',
        'mic' => 'மிக்மாக்',
        'min' => 'மின்னாங்கபௌ',
        'mk' => 'மாஸிடோனியன்',
        'ml' => 'மலையாளம்',
        'mn' => 'மங்கோலியன்',
        'mnc' => 'மன்சூ',
        'mni' => 'மணிப்புரி',
        'moe' => 'இன்னு-ஐமுன்',
        'moh' => 'மொஹாக்',
        'mos' => 'மோஸ்ஸி',
        'mr' => 'மராத்தி',
        'ms' => 'மலாய்',
        'mt' => 'மால்டிஸ்',
        'mua' => 'முன்டாங்',
        'mus' => 'க்ரீக்',
        'mwl' => 'மிரான்டீஸ்',
        'mwr' => 'மார்வாரி',
        'my' => 'பர்மீஸ்',
        'myv' => 'ஏர்ஜியா',
        'mzn' => 'மசந்தேரனி',
        'na' => 'நவ்ரூ',
        'nan' => 'மின் நான் சீனம்',
        'nap' => 'நியோபோலிடன்',
        'naq' => 'நாமா',
        'nb' => 'நார்வேஜியன் பொக்மால்',
        'nd' => 'வடக்கு தெபெலே',
        'nds' => 'லோ ஜெர்மன்',
        'ne' => 'நேபாளி',
        'new' => 'நெவாரி',
        'ng' => 'தோங்கா',
        'nia' => 'நியாஸ்',
        'niu' => 'நியூவான்',
        'nl' => 'டச்சு',
        'nmg' => 'க்வாசியோ',
        'nn' => 'நார்வேஜியன் நியூநார்ஸ்க்',
        'nnh' => 'நெகெய்ம்பூன்',
        'no' => 'நார்வேஜியன்',
        'nog' => 'நோகை',
        'non' => 'பழைய நோர்ஸ்',
        'nqo' => 'என்‘கோ',
        'nr' => 'தெற்கு தெபெலே',
        'nso' => 'வடக்கு சோதோ',
        'nus' => 'நியூர்',
        'nv' => 'நவாஜோ',
        'nwc' => 'பாரம்பரிய நேவாரி',
        'ny' => 'நயன்ஜா',
        'nym' => 'நியாம்வேஜி',
        'nyn' => 'நியான்கோலே',
        'nyo' => 'நியோரோ',
        'nzi' => 'நிஜ்மா',
        'oc' => 'ஒக்கிடன்',
        'oj' => 'ஒஜிப்வா',
        'ojb' => 'வடமேற்கு ஓஜிப்வா',
        'ojc' => 'மத்திய ஓஜிப்வா',
        'ojs' => 'ஓஜி-க்ரீ',
        'ojw' => 'மேற்கு ஓஜிப்வா',
        'oka' => 'ஒகானகன்',
        'om' => 'ஒரோமோ',
        'or' => 'ஒடியா',
        'os' => 'ஒசெட்டிக்',
        'osa' => 'ஓசேஜ்',
        'ota' => 'ஓட்டோமான் துருக்கிஷ்',
        'pa' => 'பஞ்சாபி',
        'pag' => 'பன்காசினன்',
        'pal' => 'பாஹ்லவி',
        'pam' => 'பம்பாங்கா',
        'pap' => 'பபியாமென்டோ',
        'pau' => 'பலௌவன்',
        'pcm' => 'நைஜீரியன் பிட்கின்',
        'pdc' => 'பென்சில்வேனிய ஜெர்மன்',
        'peo' => 'பழைய பெர்ஷியன்',
        'phn' => 'ஃபொனிஷியன்',
        'pi' => 'பாலி',
        'pis' => 'பிஜின்',
        'pl' => 'போலிஷ்',
        'pon' => 'ஃபோன்பெயென்',
        'pqm' => 'மலிசீட்-பஸ்ஸமகுவாடி',
        'prg' => 'பிரஷ்யன்',
        'pro' => 'பழைய ப்ரோவென்சால்',
        'ps' => 'பஷ்தோ',
        'pt' => 'போர்ச்சுகீஸ்',
        'qu' => 'க்வெச்சுவா',
        'quc' => 'கீசீ',
        'raj' => 'ராஜஸ்தானி',
        'rap' => 'ரபனுய்',
        'rar' => 'ரரோடோங்கன்',
        'rhg' => 'ரோகிஞ்சா',
        'rm' => 'ரோமான்ஷ்',
        'rn' => 'ருண்டி',
        'ro' => 'ரோமேனியன்',
        'rof' => 'ரோம்போ',
        'rom' => 'ரோமானி',
        'ru' => 'ரஷியன்',
        'rup' => 'அரோமானியன்',
        'rw' => 'கின்யாருவான்டா',
        'rwk' => 'ருவா',
        'sa' => 'சமஸ்கிருதம்',
        'sad' => 'சான்டாவே',
        'sah' => 'சக்கா',
        'sam' => 'சமாரிடன் அராமைக்',
        'saq' => 'சம்புரு',
        'sas' => 'சாசாக்',
        'sat' => 'சான்டாலி',
        'saz' => 'சௌராஷ்டிரம்',
        'sba' => 'நெகாம்பே',
        'sbp' => 'சங்கு',
        'sc' => 'சார்தீனியன்',
        'scn' => 'சிசிலியன்',
        'sco' => 'ஸ்காட்ஸ்',
        'sd' => 'சிந்தி',
        'sdh' => 'தெற்கு குர்திஷ்',
        'se' => 'வடக்கு சமி',
        'seh' => 'செனா',
        'sel' => 'செல்குப்',
        'ses' => 'கொய்ராபோரோ சென்னி',
        'sg' => 'சாங்கோ',
        'sga' => 'பழைய ஐரிஷ்',
        'sh' => 'செர்போ-குரோஷியன்',
        'shi' => 'தசேஹித்',
        'shn' => 'ஷான்',
        'si' => 'சிங்களம்',
        'sid' => 'சிடாமோ',
        'sk' => 'ஸ்லோவாக்',
        'sl' => 'ஸ்லோவேனியன்',
        'slh' => 'தெற்கு லுஷூட்சீட்',
        'sm' => 'சமோவான்',
        'sma' => 'தெற்கு சமி',
        'smj' => 'லுலே சமி',
        'smn' => 'இனாரி சமி',
        'sms' => 'ஸ்கோல்ட் சமி',
        'sn' => 'ஷோனா',
        'snk' => 'சோனின்கே',
        'so' => 'சோமாலி',
        'sog' => 'சோக்தியன்',
        'sq' => 'அல்பேனியன்',
        'sr' => 'செர்பியன்',
        'srn' => 'ஸ்ரானன் டோங்கோ',
        'srr' => 'செரெர்',
        'ss' => 'ஸ்வாடீ',
        'ssy' => 'சஹோ',
        'st' => 'தெற்கு ஸோதோ',
        'str' => 'ஸ்ட்ரெய்ட்ஸ் சாலிஷ்',
        'su' => 'சுண்டானீஸ்',
        'suk' => 'சுகுமா',
        'sus' => 'சுசு',
        'sux' => 'சுமேரியன்',
        'sv' => 'ஸ்வீடிஷ்',
        'sw' => 'ஸ்வாஹிலி',
        'swb' => 'கொமோரியன்',
        'syc' => 'பாரம்பரிய சிரியாக்',
        'syr' => 'சிரியாக்',
        'ta' => 'தமிழ்',
        'tce' => 'தெற்கு டட்சோன்',
        'te' => 'தெலுங்கு',
        'tem' => 'டிம்னே',
        'teo' => 'டெசோ',
        'ter' => 'டெரெனோ',
        'tet' => 'டெடும்',
        'tg' => 'தஜிக்',
        'tgx' => 'தகிஷ்',
        'th' => 'தாய்',
        'tht' => 'தால்டன்',
        'ti' => 'டிக்ரின்யா',
        'tig' => 'டைக்ரே',
        'tiv' => 'டிவ்',
        'tk' => 'துருக்மென்',
        'tkl' => 'டோகேலௌ',
        'tl' => 'டாகாலோக்',
        'tlh' => 'க்ளிங்கோன்',
        'tli' => 'லிங்கிட்',
        'tmh' => 'தமஷேக்',
        'tn' => 'ஸ்வானா',
        'to' => 'டோங்கான்',
        'tog' => 'நயாசா டோங்கா',
        'tok' => 'டோக்கி போனா',
        'tpi' => 'டோக் பிஸின்',
        'tr' => 'துருக்கிஷ்',
        'trv' => 'தரோகோ',
        'ts' => 'ஸோங்கா',
        'tsi' => 'ட்ஸிம்ஷியன்',
        'tt' => 'டாடர்',
        'ttm' => 'வடக்கு டட்சோன்',
        'tum' => 'தும்புகா',
        'tvl' => 'டுவாலு',
        'tw' => 'ட்வி',
        'twq' => 'டசவாக்',
        'ty' => 'தஹிதியன்',
        'tyv' => 'டுவினியன்',
        'tzm' => 'மத்திய அட்லஸ் டமசைட்',
        'udm' => 'உட்முர்ட்',
        'ug' => 'உய்குர்',
        'uga' => 'உகாரிடிக்',
        'uk' => 'உக்ரைனியன்',
        'umb' => 'அம்பொண்டு',
        'ur' => 'உருது',
        'uz' => 'உஸ்பெக்',
        'vai' => 'வை',
        've' => 'வென்டா',
        'vi' => 'வியட்நாமீஸ்',
        'vo' => 'ஒலாபூக்',
        'vot' => 'வோட்க்',
        'vun' => 'வுன்ஜோ',
        'wa' => 'ஒவாலூன்',
        'wae' => 'வால்சேர்',
        'wal' => 'வோலாய்ட்டா',
        'war' => 'வாரே',
        'was' => 'வாஷோ',
        'wbp' => 'வல்பிரி',
        'wo' => 'ஓலோஃப்',
        'wuu' => 'வூ சீனம்',
        'xal' => 'கல்மிக்',
        'xh' => 'ஹோசா',
        'xog' => 'சோகா',
        'yao' => 'யாவ்',
        'yap' => 'யாபேசே',
        'yav' => 'யாங்பென்',
        'ybb' => 'யெம்பா',
        'yi' => 'யெட்டிஷ்',
        'yo' => 'யோருபா',
        'yrl' => 'நஹீன்கட்டு',
        'yue' => 'காண்டோனீஸ்',
        'za' => 'ஜுவாங்',
        'zap' => 'ஜாபோடெக்',
        'zbl' => 'ப்லிஸ்ஸிம்பால்ஸ்',
        'zen' => 'ஜெனகா',
        'zgh' => 'ஸ்டாண்டர்ட் மொராக்கன் தமாசைட்',
        'zh' => 'சீனம்',
        'zu' => 'ஜுலு',
        'zun' => 'ஜூனி',
        'zza' => 'ஜாஜா',
    ],
    'LocalizedNames' => [
        'ar_001' => 'நவீன நிலையான அரபிக்',
        'de_AT' => 'ஆஸ்திரிய ஜெர்மன்',
        'de_CH' => 'ஸ்விஸ் ஹை ஜெர்மன்',
        'en_AU' => 'ஆஸ்திரேலிய ஆங்கிலம்',
        'en_CA' => 'கனடிய ஆங்கிலம்',
        'en_GB' => 'பிரிட்டிஷ் ஆங்கிலம்',
        'en_US' => 'அமெரிக்க ஆங்கிலம்',
        'es_419' => 'லத்தின் அமெரிக்க ஸ்பானிஷ்',
        'es_ES' => 'ஐரோப்பிய ஸ்பானிஷ்',
        'es_MX' => 'மெக்ஸிகன் ஸ்பானிஷ்',
        'fa_AF' => 'தாரி',
        'fr_CA' => 'கனடிய பிரெஞ்சு',
        'fr_CH' => 'ஸ்விஸ் பிரஞ்சு',
        'nds_NL' => 'லோ சாக்ஸன்',
        'nl_BE' => 'ஃப்லெமிஷ்',
        'pt_BR' => 'பிரேசிலிய போர்ச்சுகீஸ்',
        'pt_PT' => 'ஐரோப்பிய போர்ச்சுகீஸ்',
        'ro_MD' => 'மோல்டாவியன்',
        'sw_CD' => 'காங்கோ ஸ்வாஹிலி',
        'zh_Hans' => 'எளிதாக்கப்பட்ட சீனம்',
        'zh_Hant' => 'பாரம்பரிய சீனம்',
    ],
];
